UploadFileClientExt

Trait UploadFileClientExt 

pub trait UploadFileClientExt: UploadFileClient + Sync {
    // Provided methods
    fn upload_file(
        &self,
        path: impl AsRef<Path>,
    ) -> BoxFuture<'_, Result<DriveFile, Error<Self::Error>>> { ... }
    fn build_file(&self, path: impl AsRef<Path>) -> DriveFileBuilder<&Self> { ... }
}
An extension trait for UploadFileClient that provides convenient high-level APIs.

Provided Methods

fn upload_file( &self, path: impl AsRef<Path>, ) -> BoxFuture<'_, Result<DriveFile, Error<Self::Error>>>

Uploads the file from the specified local path.

fn build_file(&self, path: impl AsRef<Path>) -> DriveFileBuilder<&Self>

Returns a builder for creating a file on the drive.

The returned builder provides methods to customize details of the file, and you can chain them to create a file incrementally. See DriveFileBuilder for the provided methods.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors